# REST-RESP

Example resp:

```
{
    "msg": "ok",
    "pagination": {
      "next": "",
      "prev": ""
    },
    "errors": [],
    "payload": [
        {
            "id": 10,
            "full_name": "John Doe",
            "profile": {
                "screen_name": "John Doe",
            }
        }
    ]
}
```
